confidenceScore property

double confidenceScore
final

The confidence score of the top prediction, in the range [0.0, 1.0].

A value of 1.0 means the model is completely certain. A value closer to 0.5 indicates low confidence. For sentiment analysis on iOS this is the magnitude of the raw sentiment score (i.e. abs(score)).

Implementation

final double confidenceScore;