output property

String output
final

The human-readable label of the top prediction returned by the model.

For sentiment analysis this will be "Positive", "Negative", or "Neutral". For image classification it will be the object name (e.g. "Golden Retriever"). Raw per-category scores are appended in brackets for debugging purposes.

Implementation

final String output;