useGPU property

bool useGPU
final

Whether to attempt to delegate inference to the GPU or Neural Engine.

When true, the SDK will try to use hardware acceleration (e.g. Metal on iOS, NNAPI delegate on Android). Falls back to CPU automatically if the hardware delegate is not available. Defaults to true.

Implementation

final bool useGPU;