dispose method
Releases native resources held by the currently loaded model.
See OnDeviceAi.dispose for full documentation.
Implementation
Future<void> dispose() {
throw UnimplementedError('dispose() has not been implemented.');
}
Releases native resources held by the currently loaded model.
See OnDeviceAi.dispose for full documentation.
Future<void> dispose() {
throw UnimplementedError('dispose() has not been implemented.');
}